***************************************************************
*** Project 865: Muscle Changes following Stroke 		        
***
*** Main Programmer: Liqi Chen        
*** Edited and modified: Amy Adkins 
*** Notes: Mixed-effects models
***
***************************************************************;

*x "cd P:/SASODS"; *Your SASODS folder;
option nocenter;

DM log "OUT;CLEAR;LOG;CLEAR;";

*Import the datasets;

Proc Import out = Muscle
	Datafile = "/folders/myfolders/AllDataforSAS_2021_best_final.xlsx"
	DBMS = XLSX REPLACE;
	*DBMS = EXCEL REPLACE;
	Range="sheet1$A:K";
	*GETNAMES = YES;
RUN; 


*  combinding arm data for stroke and control;
Data Muscle;
 Set Muscle;
 If Stroke="Y" then Arm=Paretic;
               else Arm=Non_Dominant;
RUN;

*Subset the dataset into individual parameters;

Data Sacromere;
 Set Muscle;
 If substr(Image_ID,1,1) = "S";
RUN;

Data Fascicle;
 Set Muscle;
 If substr(Image_ID,1,1) = "F";
RUN;

Data Volume;
 Set Muscle;
 If substr(Image_ID,1,1) = "V";
RUN;

*Correct typos in datasets; 

Data Sacromere;
 Set Sacromere;
 Non_Dominant = upcase(Non_Dominant);
 Arm = upcase(Arm);
 Gender = Strip(Gender);
RUN;


Data Fascicle;
 Set Fascicle;
 Gender = Strip(Gender);
RUN;


*Centimeter to micrometer;


Proc Sort Data = Fascicle;
 by Subject Side;
RUN;

*Fascicles Average by subject and side (overall);

Proc summary Data = Fascicle MEAN;
 by Subject Side;
 var Length;
 output out=overall_means mean =;
RUN;

Data overall_means;
 set overall_means;
 rename Length = Overall_Means;
 label Length = Overall_Means;
 drop _TYPE_ _FREQ_;
RUN;


Data overall_means;
 Set overall_means;
 overall_means = overall_means*10000;
RUN;
*merging SL and FL data;

Proc Sort Data = Sacromere;
 by Subject Side;
RUN;

Data Sacromere2;
 merge Sacromere overall_means;
 by Subject Side;
RUN;

* SSN;

Data Sacromere2;
 set Sacromere2;
 Overall_SSN = Overall_Means/Length;
RUN;


* PCSA;
Proc Sort Data = Volume;
by Subject Side;
RUN;

Proc Summary Data = Volume MEAN;
 by Subject Side;
 var Length;
 output out=vol mean=;
RUN;

Data vol;
 set vol;
 rename Length = Vol2;
 label Length = Vol2;
 drop _TYPE_ _FREQ_;
RUN;

Proc Sort Data = Sacromere2;
 by Subject Side;
RUN;

Data PCSA;
 merge Sacromere2 Vol;
 by Subject Side;
RUN;

Data PCSA;
 set PCSA;
 OFL = Overall_SSN*2.7/10000;
 PCSA = Vol2/OFL;
RUN;


** GLMM;
Proc Mixed Data = Sacromere Plots=all; *Diagnostic plots;
 Class Subject Image_ID Side Stroke(ref="N") Arm;
 Model Length = Stroke Arm Stroke*Arm/ s;
 Random subject side(subject);
 Lsmeans Stroke*Arm/ diff cl;
 estimate 'differences in differences'
              Stroke*Arm 1 -1
                         -1 1 /e;
RUN;

Proc Mixed Data = Fascicle Plots=all; *Diagnostic plots;
 Class Subject Image_ID Side Stroke(ref="N") Arm;
 Model Length = Stroke Arm Stroke*Arm/ s;
 Random subject side(subject);
 Lsmeans Stroke*Arm/ diff cl;
 estimate 'differences in differences'
              Stroke*Arm 1 -1
                         -1 1 /e;
RUN;


Proc Mixed Data = Sacromere2 Plots=all; *Diagnostic plots;
 Class Subject Image_ID Side Stroke(ref="N") Arm;
 Model Overall_SSN = Stroke Arm Stroke*Arm/ s;
 Random subject side(subject);
 Lsmeans Stroke*Arm/ diff cl;
 estimate 'differences in differences'
              Stroke*Arm 1 -1
                         -1 1 /e;
RUN;


Proc Mixed Data = PCSA Plots=all; *Diagnostic plots;
 Class Subject Image_ID Side Stroke(ref="N") Arm;
 Model PCSA = Stroke Arm Stroke*Arm/ s;
 Random Subject side(Subject);
 Lsmeans Stroke*Arm/ diff cl;
 estimate 'differences in differences'
              Stroke*Arm 1 -1
                         -1 1 /e;
RUN;

** GLMM;

*Mann-Whitney U test;

Proc Import out = Muscle
	Datafile = "/folders/myfolders/AllDataforSAS_2021_best_final.xlsx"
	DBMS = XLSX REPLACE;
	*DBMS = EXCEL REPLACE;
	Range="sheet1$A:K";
	*GETNAMES = YES;
RUN; 

Data Muscle;
 Set Muscle;
 If Stroke="Y" then Arm=Paretic;
               else Arm=Non_Dominant;
RUN;

Data Volume;
 Set Muscle;
 If substr(Image_ID,1,1) = "V";
RUN;

*Part 1;

Data strokey;
 Set Volume;
 If Stroke = "Y";
RUN;

Data strokeyarmy;
 Set strokey;
 If Arm = "Y";
 Rename Image_ID=Image_IDY
        Side=SideY
        Stroke=StrokeY
        Paretic=PareticY
        Non_Dominant=Non_DominantY
        Length=LengthY
        FM=FMY
        TSS=TSSY
        Gender=GenderY
        Age=AgeY
        Arm=ArmY;
RUN;

Data strokeyarmn;
 Set strokey;
 If Arm = "N";
  Rename Image_ID=Image_IDN
        Side=SideN
        Stroke=StrokeN
        Paretic=PareticN
        Non_Dominant=Non_DominantN
        Length=LengthN
        FM=FMN
        TSS=TSSN
        Gender=GenderN
        Age=AgeN
        Arm=ArmN;
RUN;

Data finalstrokey; 
  Merge strokeyarmy strokeyarmn; 
  By Subject; 
RUN; 

Data finalstrokey;
 Set finalstrokey;
 Difference=LengthN-LengthY;
 Rename StrokeY=Stroke;
RUN;

Data finalstrokey (Keep=Subject Stroke Difference);
 Set finalstrokey;
RUN;

*Part 2;

Data stroken;
 Set Volume;
 If Stroke = "N";
RUN;

Data strokenarmy;
 Set stroken;
 If Arm = "Y";
 Rename Image_ID=Image_IDY
        Side=SideY
        Stroke=StrokeY
        Paretic=PareticY
        Non_Dominant=Non_DominantY
        Length=LengthY
        FM=FMY
        TSS=TSSY
        Gender=GenderY
        Age=AgeY
        Arm=ArmY;
RUN;

Data strokenarmn;
 Set stroken;
 If Arm = "N";
  Rename Image_ID=Image_IDN
        Side=SideN
        Stroke=StrokeN
        Paretic=PareticN
        Non_Dominant=Non_DominantN
        Length=LengthN
        FM=FMN
        TSS=TSSN
        Gender=GenderN
        Age=AgeN
        Arm=ArmN;
RUN;

Data finalstroken; 
  Merge strokenarmy strokenarmn; 
  By Subject; 
RUN; 

Data finalstroken;
 Set finalstroken;
 Difference=LengthN-LengthY;
 Rename StrokeY=Stroke;
RUN;

Data finalstroken (Keep=Subject Stroke Difference);
 Set finalstroken;
RUN;

Data finalvolume;
 Set finalstrokey finalstroken;
RUN;

proc means data=finalvolume n nmiss mean std stderr median min max qrange maxdec=4;
class stroke;
var difference;
RUN;

proc npar1way data=finalvolume wilcoxon;
class stroke;
var difference;
run;

